@@ -81,6 +81,7 @@ int valid_mntpt( const char* mntpt )
         return 0;
 
     if( fstab_has_mntpt( "/proc/mounts", mntpt, NULL, 0 ) ||
+        fstab_has_mntpt( "/etc/fstab", mntpt, NULL, 0 ) ||
         fstab_has_mntpt( "/etc/mtab", mntpt, NULL, 0 ) )
         return 0;
 
@@ -190,6 +191,12 @@ main( int argc, const char** argv )
     if (getenv ("PMOUNT_DEBUG"))
         enable_debug = 1;
 
+    /* if this is an fstab device, use mount right away */
+    if( fstab_has_device( "/etc/fstab", devarg, NULL, NULL ) ) {
+	debug( "%s is in /etc/fstab, calling mount\n", devarg );
+	return spawnl( SPAWN_SEARCHPATH, "mount", "mount", devarg, NULL );
+    }
+
     /* initialize hal connection */
     dbus_error_init( &error );
     dbus_conn = dbus_bus_get( DBUS_BUS_SYSTEM, &error );
@@ -304,7 +311,7 @@ main( int argc, const char** argv )
 
     const char* s;
     for( s = options; s; s = strchr( s, ',') ) {
-        ++s; /* skip comma */
+        while (*s == ',') ++s; /* skip comma */
         if( !strncmp( s, "exec", 4 ) )
             exec = TRUE;
         else if( !strncmp( s, "noexec", 6 ) )
